@@ -2,6 +2,7 @@ from botty_core import CompositeHandler
 
 from .buttons import CallbackButton, UrlButton
 from .callbacks import QueryCallback, ReplyCallback, TextCallback
+from .contexts import QueryContext, ReplyContext, TextContext
 from .handlers import (
     CommandHandler,
     CommandReplyHandler,
@@ -61,4 +62,7 @@ __all__ = [
     "ReplyCallback",
     "TextCallback",
     "QueryCallback",
+    "ReplyContext",
+    "QueryContext",
+    "TextContext",
 ]
