@@ -9,14 +9,14 @@ from botty.keyboards import InlineKeyboard
 
 TextGetter = Callable[[ReplyContext], str | None]
 KeyboardGetter = Callable[[ReplyContext], InlineKeyboard | None]
-ReplyCallbackText = str | TextGetter
+ReplyCallbackText = str | TextGetter | None
 ReplyCallbackKeyboard = InlineKeyboard | KeyboardGetter | None
 
 
 class ReplyCallback(Callback):
     def __init__(
         self,
-        text: ReplyCallbackText,
+        text: ReplyCallbackText = None,
         keyboard: ReplyCallbackKeyboard = None,
     ) -> None:
         super().__init__()
