@@ -1,5 +1,4 @@
-from botty.callbacks import ReplyCallback
-from botty.keyboards import InlineKeyboard
+from botty.callbacks import ReplyCallback, ReplyCallbackKeyboard, ReplyCallbackText
 from botty.triggers import CommandTrigger
 
 from .update import UpdateHandler
@@ -18,8 +17,8 @@ class CommandReplyHandler(CommandHandler):
     def __init__(
         self,
         command: str,
-        text: str | None = None,
-        keyboard: InlineKeyboard | None = None,
+        text: ReplyCallbackText,
+        keyboard: ReplyCallbackKeyboard = None,
     ) -> None:
         callback = ReplyCallback(text, keyboard)
         super().__init__(callback, command)
