@@ -1,6 +1,5 @@
 from botty.buttons import CallbackButton
-from botty.callbacks import ReplyCallback
-from botty.keyboards import InlineKeyboard
+from botty.callbacks import ReplyCallback, ReplyCallbackKeyboard, ReplyCallbackText
 from botty.triggers import QueryTrigger
 
 from .update import UpdateHandler
@@ -10,7 +9,7 @@ class QueryHandler(UpdateHandler):
     def __init__(
         self,
         callback: ReplyCallback,
-        button: CallbackButton | None = None,
+        button: CallbackButton,
     ) -> None:
         self._button = button
         super().__init__(callback)
@@ -22,9 +21,9 @@ class QueryHandler(UpdateHandler):
 class QueryReplyHandler(QueryHandler):
     def __init__(
         self,
-        button: CallbackButton | None = None,
-        text: str | None = None,
-        keyboard: InlineKeyboard | None = None,
+        button: CallbackButton,
+        text: ReplyCallbackText,
+        keyboard: ReplyCallbackKeyboard = None,
     ) -> None:
         callback = ReplyCallback(text, keyboard)
         super().__init__(callback, button)
