@@ -1,4 +1,4 @@
-from .aliases import Context, PTBCallback, PTBHandler, ReplyMarkup
+from .aliases import PTBCallback, PTBContext, PTBHandler, ReplyMarkup
 from .bot import Bot
 from .chat import Chat
 from .message import Message
@@ -14,7 +14,7 @@ __all__ = [
     "Update",
     "Message",
     "PTBHandler",
-    "Context",
+    "PTBContext",
     "ReplyMarkup",
     "PTBCallback",
 ]
